// AUTO-GENERATED BY UpdateGenVersion.bat 6ae219f789d1ca9ab8cc62f9f9e47587ea40bfe7
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "6ae219f789d1ca9ab8cc62f9f9e47587ea40bfe7";
